@@ -1,8 +1,28 @@
 // ***************************************************************** -*- C++ -*-
-// geotag.cpp, $Rev: 2286 $
+/*
+ * Copyright (C) 2004-2021 Exiv2 authors
+ * This program is part of the Exiv2 distribution.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
+ */
+// geotag.cpp
 // Sample program to read gpx files and update images with GPS tags
+// g++ geotag.cpp -o geotag -lexiv2 -lexpat
 
 #include <exiv2/exiv2.hpp>
+#include "unused.h"
 
 #include <iostream>
 #include <iomanip>
@@ -10,7 +30,7 @@
 #include <algorithm>
 
 #include <stdio.h>
-#include <stdlib.h>
+#include <cstdlib>
 #include <time.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -32,9 +52,6 @@ using namespace std;
 #ifndef  lengthof
 #define  lengthof(x) (sizeof(*x)/sizeof(x))
 #endif
-#ifndef nil
-#define nil NULL
-#endif
 
 #if defined(_MSC_VER) || defined(__MINGW__)
 #include <windows.h>
@@ -58,8 +75,6 @@ char*    realpath(const char* file,char* path);
 #define _MAX_PATH 1024
 #endif
 
-#define UNUSED(x) (void)(x)
-
 // prototypes
 class Options;
 int getFileType(const char* path ,Options& options);
@@ -88,6 +103,7 @@ public:
     bool        version;
     bool        dst;
     bool        dryrun;
+    bool        ascii;
 
     Options()
     {
@@ -96,6 +112,7 @@ public:
         version     = false;
         dst         = false;
         dryrun      = false;
+        ascii       = false;
     }
 
     virtual ~Options() {} ;
@@ -112,6 +129,7 @@ enum                        // keyword indices
 ,   kwVERSION
 ,   kwDST
 ,   kwDRYRUN
+,   kwASCII
 ,   kwVERBOSE
 ,   kwADJUST
 ,   kwTZ
@@ -134,15 +152,46 @@ enum
 ,   typeMax       = 7
 };
 
+// forward declaration
+class Position;
+
+// globals
+typedef std::map<time_t,Position>           TimeDict_t;
+typedef std::map<time_t,Position>::iterator TimeDict_i;
+typedef std::vector<std::string>            strings_t;
+const char*  gDeg = NULL ; // string "°" or "deg"
+TimeDict_t   gTimeDict   ;
+strings_t    gFiles;
+
 // Position (from gpx file)
 class Position
 {
 public:
-             Position(time_t time,double lat,double lon,double ele) : time_(time),lon_(lon),lat_(lat),ele_(ele) {};
-             Position() { time_=0 ; lon_=0.0 ; lat_=0.0 ; ele_=0.0 ; };
-    virtual ~Position() {} ;
+    Position(time_t time, double lat, double lon, double ele) :
+        time_(time)
+      , lon_(lon)
+      , lat_(lat)
+      , ele_(ele)
+      , delta_(0)
+    {}
+
+    Position():
+        time_(0)
+      , lon_(0.0)
+      , lat_(0.0)
+      , ele_(0.0)
+      , delta_(0)
+    { }
+
+    virtual ~Position() {}
 //  copy constructor
-    Position(const Position& o) : time_(o.time_),lon_(o.lon_),lat_(o.lat_),ele_(o.ele_) {};
+    Position(const Position& o) :
+        time_(o.time_)
+      , lon_(o.lon_)
+      , lat_(o.lat_)
+      , ele_(o.ele_)
+      , delta_(o.delta_)
+    {}
 
 //  instance methods
     bool good()                 { return time_ || lon_ || lat_ || ele_ ; }
@@ -191,13 +240,13 @@ std::string Position::toExifTimeStamp(std::string& t)
     const char* arg = t.c_str();
     int HH = 0 ;
     int mm = 0 ;
-    int SS = 0 ;
+    int SS1 = 0 ;
     if ( strstr(arg,":") || strstr(arg,"-") ) {
-        int  YY,MM,DD    ;
-        char a,b,c,d,e   ;
-        sscanf(arg,"%d%c%d%c%d%c%d%c%d%c%d",&YY,&a,&MM,&b,&DD,&c,&HH,&d,&mm,&e,&SS);
+        int YY=0,MM=0,DD=0;
+        char a=0,b=0,c=0,d=0,e=0;
+        sscanf(arg,"%d%c%d%c%d%c%d%c%d%c%d",&YY,&a,&MM,&b,&DD,&c,&HH,&d,&mm,&e,&SS1);
     }
-    sprintf(result,"%d/1 %d/1 %d/1",HH,mm,SS);
+    sprintf(result,"%d/1 %d/1 %d/1",HH,mm,SS1);
     return std::string(result);
 }
 
@@ -213,7 +262,7 @@ std::string Position::toExifString(double d,bool bRational,bool bLat)
 {
     const char* NS   = d>=0.0?"N":"S";
     const char* EW   = d>=0.0?"E":"W";
-	const char* NSEW = bLat  ? NS: EW;
+    const char* NSEW = bLat  ? NS: EW;
     if ( d < 0 ) d = -d;
     int deg = (int) d;
         d  -= deg;
@@ -223,7 +272,10 @@ std::string Position::toExifString(double d,bool bRational,bool bLat)
         d  *= 60;
     int sec = (int)d;
     char result[200];
-    sprintf(result,bRational ? "%d/1 %d/1 %d/1%s" : "%03d.%02d'%02d\"%s" ,deg,min,sec,bRational?"":NSEW);
+    if ( bRational )
+        sprintf(result,"%d/1 %d/1 %d/1" ,deg,min,sec);
+    else
+        sprintf(result,"%03d%s%02d'%02d\"%s" ,deg,gDeg,min,sec,NSEW);
     return std::string(result);
 }
 
@@ -236,25 +288,29 @@ std::string Position::toString()
     return std::string(result);
 }
 
+// defaults
 int    Position::adjust_   = 0;
 int    Position::tz_       = timeZoneAdjust();
 int    Position::dst_      = 0;
 time_t Position::deltaMax_ = 60 ;
 
-// globals
-typedef std::map<time_t,Position>           TimeDict_t;
-typedef std::map<time_t,Position>::iterator TimeDict_i;
-typedef std::vector<std::string>            strings_t;
-TimeDict_t   gTimeDict ;
-strings_t    gFiles;
-
 ///////////////////////////////////////////////////////////
 // UserData - used by XML Parser
 class UserData
 {
 public:
-    UserData(Options& options) : indent(0),count(0),nTrkpt(0),bTime(false),bEle(false),options_(options) {};
-    virtual ~UserData() {} ;
+    explicit UserData(Options& options):
+        indent(0)
+      , count(0)
+      , nTrkpt(0)
+      , bTime(false)
+      , bEle(false)
+      , ele(0.0)
+      , lat(0.0)
+      , lon(0.0)
+      , options_(options)
+    {}
+    virtual ~UserData() {}
 
 //  public data members
     int         indent;
@@ -310,16 +366,6 @@ static void endElement(void* userData, const char* name)
             printf("trkseg %s begin ",me->now.getTimeString().c_str());
         }
 
-        // printf("lat,lon = %f,%f ele = %f xml = %s exif = %s\n",me->lat,me->lon,me->ele,me->xmlt.c_str(),me->exift.c_str());
-
-        // if we have a good previous position
-        // add missed entries to timedict
-        //if ( me->prev.good() && (me->now.getTime() - me->prev.getTime()) < Position::timeDiffMax ) {
-        //  time_t missed = me->prev.getTime() ;
-        //  while ( ++missed < me->now.getTime() )
-        //      gTimeDict[missed] = me->prev ; // Position(missed,me->lat,me->lon,me->ele) ;
-        //}
-
         // remember our location and put it in gTimeDict
         gTimeDict[me->time] = me->now ;
         me->prev = me->now ;
@@ -349,7 +395,7 @@ void charHandler(void* userData,const char* s,int len)
             }
             me->bTime=false;
         }
-        if ( me->bEle && len > 5 ) {
+        if ( me->bEle && len > 2 ) {
             if ( len < l_max ) {
                 memcpy(buffer,s,len);
                 buffer[len]=0;
@@ -377,32 +423,20 @@ time_t parseTime(const char* arg,bool bAdjust)
         // <time>2012-07-14T17:33:16Z</time>
 
         if ( strstr(arg,":") || strstr(arg,"-") ) {
-            int  YY,MM,DD,HH,mm,SS ;
-            char a,b,c,d,e   ;
-            sscanf(arg,"%d%c%d%c%d%c%d%c%d%c%d",&YY,&a,&MM,&b,&DD,&c,&HH,&d,&mm,&e,&SS);
+            int  YY=0,MM=0,DD=0,HH=0,mm=0,SS1=0;
+            char a=0,b=0,c=0,d=0,e=0;
+            sscanf(arg,"%d%c%d%c%d%c%d%c%d%c%d",&YY,&a,&MM,&b,&DD,&c,&HH,&d,&mm,&e,&SS1);
 
             struct tm T;
-    #if 0
-            int tm_sec;     /* seconds (0 - 60) */
-            int tm_min;     /* minutes (0 - 59) */
-            int tm_hour;    /* hours (0 - 23) */
-            int tm_mday;    /* day of month (1 - 31) */
-            int tm_mon;     /* month of year (0 - 11) */
-            int tm_year;    /* year - 1900 */
-            int tm_wday;    /* day of week (Sunday = 0) */
-            int tm_yday;    /* day of year (0 - 365) */
-            int tm_isdst;   /* is summer time in effect? */
-            char *tm_zone;  /* abbreviation of timezone name */
-            long tm_gmtoff; /* offset from UTC in seconds */
-    #endif
             memset(&T,0,sizeof(T));
             T.tm_min  = mm  ;
             T.tm_hour = HH  ;
-            T.tm_sec  = SS  ;
+            T.tm_sec  = SS1 ;
             if ( bAdjust ) T.tm_sec -= Position::Adjust();
             T.tm_year = YY -1900 ;
             T.tm_mon  = MM -1    ;
             T.tm_mday = DD  ;
+            T.tm_isdst = -1 ; // determine value automatically (otherwise hour may shift)
             result = mktime(&T);
         }
     } catch ( ... ) {};
@@ -424,7 +458,7 @@ int timeZoneAdjust()
     struct tm lcopy = *localtime(&now);
     time_t    gmt   =  timegm(&lcopy) ; // timegm modifies lcopy
     offset          = (int) ( ((long signed int) gmt) - ((long signed int) now) ) ;
-#elif defined(OS_SOLARIS)
+#elif defined(OS_SOLARIS) || defined(__sun__)
     struct tm local = *localtime(&now) ;
     time_t local_tt = (int) mktime(&local);
     time_t time_gmt = (int) mktime(gmtime(&now));
@@ -432,14 +466,13 @@ int timeZoneAdjust()
 #else
     struct tm local = *localtime(&now) ;
     offset          = local.tm_gmtoff ;
-#endif
 
-#if 0
-    // debugging code
+#if EXIV2_DEBUG_MESSAGES
     struct tm utc = *gmtime(&now);
     printf("utc  :  offset = %6d dst = %d time = %s", 0     ,utc  .tm_isdst, asctime(&utc  ));
     printf("local:  offset = %6d dst = %d time = %s", offset,local.tm_isdst, asctime(&local));
     printf("timeZoneAdjust = %6d\n",offset);
+#endif
 #endif
     return offset ;
 }
@@ -451,7 +484,7 @@ string getExifTime(const time_t t)
     return result ;
 }
 
-std::string makePath(std::string dir,std::string file)
+std::string makePath(const std::string& dir, const std::string& file)
 {
     return dir + std::string(EXV_SEPARATOR_STR) + file ;
 }
@@ -591,13 +624,11 @@ bool readImage(const char* path,Options& /* options */)
     return bResult ;
 }
 
-time_t readImageTime(std::string path,std::string* pS=NULL)
+time_t readImageTime(const std::string& path,std::string* pS=NULL)
 {
     using namespace Exiv2;
 
     time_t       result       = 0 ;
-	static std::map<std::string,time_t> cache;
-	if ( cache.count(path) == 1 ) return cache[path];
 
     const char* dateStrings[] =
     { "Exif.Photo.DateTimeOriginal"
@@ -605,21 +636,21 @@ time_t readImageTime(std::string path,std::string* pS=NULL)
     , "Exif.Image.DateTime"
     , NULL
     };
-    const char* ds            = dateStrings[0] ;
 
-    while ( !result && ds++  ) {
+    for (size_t i = 0; !result && dateStrings[i]; i++) {
+        const char* dateString = dateStrings[i] ;
         try {
             Image::AutoPtr image = ImageFactory::open(path);
             if ( image.get() ) {
                 image->readMetadata();
                 ExifData &exifData = image->exifData();
-            //  printf("%s => %s\n",(ds-1), exifData[ds-1].toString().c_str());
-                result = parseTime(exifData[ds-1].toString().c_str(),true);
-                if ( result && pS ) *pS = exifData[ds-1].toString();
+            //  printf("%s => %s\n",dateString, exifData[dateString].toString().c_str());
+                result = parseTime(exifData[dateString].toString().c_str(),true);
+                if ( result && pS ) *pS = exifData[dateString].toString();
             }
         } catch ( ... ) {};
     }
-	if ( result ) cache[path] = result;
+
     return result ;
 }
 
@@ -642,12 +673,14 @@ int readFile(const char* path,Options /* options */)
     FILE* f     = fopen(path,"r");
     int nResult = f ? typeFile : typeUnknown;
     if (  f ) {
-        const char* docs[] = { ".doc",".txt", nil };
-        const char* code[] = { ".cpp",".h"  ,".pl" ,".py" ,".pyc", nil };
         const char*  ext   = strstr(path,".");
         if  ( ext ) {
-            if ( sina(ext,docs) ) nResult = typeDoc;
-            if ( sina(ext,code) ) nResult = typeCode;
+            const char* docs[] = { ".doc",".txt", NULL };
+            const char* code[] = { ".cpp",".h"  ,".pl" ,".py" ,".pyc", NULL };
+            if ( sina(ext,docs) )
+                nResult = typeDoc;
+            if ( sina(ext,code) )
+                nResult = typeCode;
         }
     }
     if ( f ) fclose(f) ;
@@ -693,7 +726,7 @@ int help(const char* program,char const* words[],int nWords,bool /*bVerbose*/)
         if ( words[i] )
             printf("%c-%s%s",i?'|':'{',words[i],i>(-kwNOVALUE)?" value":"");
     }
-    printf("} path+\n");
+    printf("}+ path+\n");
     return 0;
 }
 
@@ -731,7 +764,7 @@ int parseTZ(const char* adjust)
 {
     int   h=0;
     int   m=0;
-    char  c  ;
+    char  c=0;
     try {
         sscanf(adjust,"%d%c%d",&h,&c,&m);
     } catch ( ... ) {} ;
@@ -739,7 +772,7 @@ int parseTZ(const char* adjust)
     return (3600*h)+(60*m);
 }
 
-bool mySort(std::string a,std::string b)
+bool mySort(const std::string& a, const std::string& b)
 {
     time_t A = readImageTime(a);
     time_t B = readImageTime(b);
@@ -748,6 +781,12 @@ bool mySort(std::string a,std::string b)
 
 int main(int argc,const char* argv[])
 {
+    Exiv2::XmpParser::initialize();
+    ::atexit(Exiv2::XmpParser::terminate);
+#ifdef EXV_ENABLE_BMFF
+    Exiv2::enableBMFF();
+#endif
+
     int result=0;
     const char* program = argv[0];
 
@@ -766,6 +805,7 @@ int main(int argc,const char* argv[])
     keywords[kwVERSION ] = "version";
     keywords[kwVERBOSE ] = "verbose";
     keywords[kwDRYRUN  ] = "dryrun";
+    keywords[kwASCII   ] = "ascii";
     keywords[kwDST     ] = "dst";
     keywords[kwADJUST  ] = "adjust";
     keywords[kwTZ      ] = "tz";
@@ -782,6 +822,7 @@ int main(int argc,const char* argv[])
     shorts["-D"] = "-delta";
     shorts["-s"] = "-delta";
     shorts["-X"] = "-dryrun";
+    shorts["-a"] = "-ascii";
 
     Options options ;
     options.help    = sina(keywords[kwHELP   ],argv) || argc < 2;
@@ -789,7 +830,7 @@ int main(int argc,const char* argv[])
     options.dryrun  = sina(keywords[kwDRYRUN ],argv);
     options.version = sina(keywords[kwVERSION],argv);
     options.dst     = sina(keywords[kwDST    ],argv);
-    options.dryrun  = sina(keywords[kwDRYRUN ],argv);
+    options.ascii   = sina(keywords[kwASCII  ],argv);
 
     for ( int i = 1 ; !result && i < argc ; i++ ) {
         const char* arg   = argv[i++];
@@ -804,14 +845,15 @@ int main(int argc,const char* argv[])
         if ( needv && !value) key = kwNEEDVALUE;
 
         switch ( key ) {
-            case kwDST      : options.dst     = true ; break;
-            case kwHELP     : options.help    = true ; break;
-            case kwVERSION  : options.version = true ; break;
-            case kwDRYRUN   : options.dryrun  = true ; break;
-            case kwVERBOSE  : options.verbose = true ; break;
-            case kwTZ       : Position::tz_      = parseTZ(value);break;
-            case kwADJUST   : Position::adjust_  = ivalue;break;
-            case kwDELTA    : Position::deltaMax_= ivalue;break;
+            case kwDST      : options.dst         = true ; break;
+            case kwHELP     : options.help        = true ; break;
+            case kwVERSION  : options.version     = true ; break;
+            case kwDRYRUN   : options.dryrun      = true ; break;
+            case kwVERBOSE  : options.verbose     = true ; break;
+            case kwASCII    : options.ascii       = true ; break;
+            case kwTZ       : Position::tz_       = parseTZ(value);break;
+            case kwADJUST   : Position::adjust_   = ivalue;break;
+            case kwDELTA    : Position::deltaMax_ = ivalue;break;
             case kwNEEDVALUE: fprintf(stderr,"error: %s requires a value\n",arg); result = resultSyntaxError ; break ;
             case kwSYNTAX   : default:
             {
@@ -819,24 +861,29 @@ int main(int argc,const char* argv[])
                 if ( options.verbose ) printf("%s %s ",arg,types[type]) ;
                 if ( type == typeImage ) {
                     time_t t    = readImageTime(std::string(arg)) ;
-                    char*  path = realpath(arg,NULL);
+#ifdef __APPLE__
+                    char   buffer[1024];
+#else
+                    char*  buffer = NULL;
+#endif
+                    char*  path = realpath(arg,buffer);
                     if  ( t && path ) {
                         if ( options.verbose) printf("%s %ld %s",path,(long int)t,asctime(localtime(&t)));
                         gFiles.push_back(path);
                     }
-                    if ( path ) :: free((void*) path);
+                    if ( path && path != buffer ) ::free((void*) path);
                 }
                 if ( type == typeUnknown ) {
                     fprintf(stderr,"error: illegal syntax %s\n",arg);
                     result = resultSyntaxError ;
                 }
-                if ( options.verbose ) printf("\n") ;
-            }break;
+            } break;
         }
     }
 
     if ( options.help    ) ::help(program,keywords,kwMAX,options.verbose);
     if ( options.version ) ::version(program);
+    gDeg = options.ascii ? "deg" : "°";
 
     if ( !result ) {
         sort(gFiles.begin(),gFiles.end(),mySort);
@@ -852,82 +899,34 @@ int main(int argc,const char* argv[])
                 s = abs(s);
             int m = s/60  ;
                 s-= m*60  ;
-            printf("tz,dsl,adjust = %d,%d,%d total = %dsecs (= %d:%d:%d)\n",t,d,a,A,h,m,s);
+            printf("tz,dst,adjust = %d,%d,%d total = %dsecs (= %d:%d:%d)\n",t,d,a,A,h,m,s);
         }
-        for ( size_t p = 0 ; !options.dryrun && p < gFiles.size() ; p++ ) {
-            std::string arg = gFiles[p] ;
+/*
+        if ( options.verbose ) {
+            printf("Time Dictionary\n");
+            for ( TimeDict_i it = gTimeDict.begin() ;  it != gTimeDict.end() ; it++ ) {
+                std::string sTime = getExifTime(it->first);
+                Position*   pPos  = &it->second;
+                std::string sPos  = Position::toExifString(pPos->lat(),false,true)
+                                  + " "
+                                  + Position::toExifString(pPos->lon(),false,true)
+                                  ;
+                printf("%s %s\n",sTime.c_str(), sPos.c_str());
+            }
+        }
+*/
+        for ( size_t p = 0 ; p < gFiles.size() ; p++ ) {
+            std::string path  = gFiles[p] ;
             std::string stamp ;
             try {
-                time_t t       = readImageTime(arg,&stamp) ;
+                time_t t       = readImageTime(path,&stamp) ;
                 Position* pPos = searchTimeDict(gTimeDict,t,Position::deltaMax_);
-                Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open(gFiles[p]);
+                Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open(path);
                 if ( image.get() ) {
                     image->readMetadata();
                     Exiv2::ExifData& exifData = image->exifData();
-#if 0
-                    /*
-					char* keys[]={ "Exif.Image.GPSTag"
-						         , "Exif.GPSInfo.GPSProcessingMethod"
-					             , "Exif.GPSInfo.GPSAltitudeRef"
-							     , "Exif.GPSInfo.GPSVersionID"
-                                 , "Exif.GPSInfo.GPSProcessingMethod"
-                                 , "Exif.GPSInfo.GPSVersionID"
-                                 , "Exif.GPSInfo.GPSMapDatum"
-                                 , "Exif.GPSInfo.GPSLatitude"
-                                 , "Exif.GPSInfo.GPSLongitude"
-                                 , "Exif.GPSInfo.GPSAltitude"
-                                 , "Exif.GPSInfo.GPSAltitudeRef"
-                                 , "Exif.GPSInfo.GPSLatitudeRef"
-                                 , "Exif.GPSInfo.GPSLongitudeRef"
-                                 , "Exif.GPSInfo.GPSDateStamp"
-                                 , "Exif.GPSInfo.GPSTimeStamp"
-					};
-					static int bPrint = true ;
-					for ( int k = 0 ; k < 15 ;   k++ ) {
-						try {
-							if ( bPrint ) printf("erasing %s\n",keys[k]);
-							Exiv2::ExifKey  key = Exiv2::ExifKey(keys[k]);
-							Exiv2::ExifData::iterator kk = exifData.findKey(key);
-							if ( kk != exifData.end() ) exifData.erase(kk);
-						} catch (...) {};
-					}
-					bPrint = false;
-                    */
-#endif
-#if 0
-					Exiv2::ExifData::const_iterator end = exifData.end();
-					for (Exiv2::ExifData::iterator i = exifData.begin(); i != end; ++i) {
-						char name[100];
-						strcpy(name,i->key().c_str());
-						// std::cout << "sniff " << i->key() << std::endl;
-						if ( strstr(name,"GPS") )  {
-							Exiv2::ExifData::iterator pos;
-							Exiv2::ExifKey exifKey = Exiv2::ExifKey(name);
-							pos = exifData.findKey(exifKey);
-							while( pos != exifData.end()) {
-								exifData.erase(pos);
-							}
-						}
-					}
-#endif
-					if ( pPos ) {
-						/*
-						   struct _stat buf;
-   int result;
-   char timebuf[26];
-   char* filename = "crt_stat.c";
-   errno_t err;
-
-   // Get data associated with "crt_stat.c":
-   result = _stat( filename, &buf );
-
-   int _utime(
-   const char *filename,
-   struct _utimbuf *times
-);
-   */
-
-                        exifData["Exif.GPSInfo.GPSProcessingMethod" ] = "65 83 67 73 73 0 0 0 72 89 66 82 73 68 45 70 73 88"; // ASCII HYBRID-FIX
+                    if ( pPos ) {
+                        exifData["Exif.GPSInfo.GPSProcessingMethod" ] = "charset=Ascii HYBRID-FIX";
                         exifData["Exif.GPSInfo.GPSVersionID"        ] = "2 2 0 0";
                         exifData["Exif.GPSInfo.GPSMapDatum"         ] = "WGS-84";
 
@@ -936,19 +935,19 @@ int main(int argc,const char* argv[])
                         exifData["Exif.GPSInfo.GPSAltitude"         ] = Position::toExifString(pPos->ele());
 
                         exifData["Exif.GPSInfo.GPSAltitudeRef"      ] = pPos->ele()<0.0?"1":"0";
-						exifData["Exif.GPSInfo.GPSLatitudeRef"      ] = pPos->lat()>0?"N":"S";
-						exifData["Exif.GPSInfo.GPSLongitudeRef"     ] = pPos->lon()>0?"E":"W";
+                        exifData["Exif.GPSInfo.GPSLatitudeRef"      ] = pPos->lat()>0?"N":"S";
+                        exifData["Exif.GPSInfo.GPSLongitudeRef"     ] = pPos->lon()>0?"E":"W";
 
                         exifData["Exif.GPSInfo.GPSDateStamp"        ] = stamp;
                         exifData["Exif.GPSInfo.GPSTimeStamp"        ] = Position::toExifTimeStamp(stamp);
-						exifData["Exif.Image.GPSTag"                ] = 4908;
+                        exifData["Exif.Image.GPSTag"                ] = 4908;
 
-						printf("%s %s % 2d\n",arg.c_str(),pPos->toString().c_str(),pPos->delta());
+                        printf("%s %s % 2d\n",path.c_str(),pPos->toString().c_str(),pPos->delta());
                     } else {
-                        printf("%s *** not in time dict ***\n",arg.c_str());
+                        printf("%s *** not in time dict ***\n",path.c_str());
                     }
-                    image->writeMetadata();
-				}
+                    if ( !options.dryrun ) image->writeMetadata();
+                }
             } catch ( ... ) {};
         }
     }
