@@ -1,7 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2017 Andreas Huggel <ahuggel@gmx.net>
- *
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -20,15 +19,10 @@
  */
 /*
   File:      datasets.cpp
-  Version:   $Rev$
   Author(s): Brad Schick (brad) <brad@robotbattle.com>
              Gilles Caulier (gc) <caulier dot gilles at gmail dot com>
   History:   24-Jul-04, brad: created
  */
-// *****************************************************************************
-#include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id$")
-
 // *****************************************************************************
 // included header files
 #include "datasets.hpp"
@@ -530,14 +524,14 @@ namespace Exiv2 {
     uint16_t IptcDataSets::dataSet(const std::string& dataSetName,
                                    uint16_t recordId)
     {
-        uint16_t dataSet;
+        uint16_t dataSet = 0;
         int idx = dataSetIdx(dataSetName, recordId);
         if (idx != -1) {
             // dataSetIdx checks the range of recordId
             dataSet = records_[recordId][idx].number_;
         }
         else {
-            if (!isHex(dataSetName, 4, "0x")) throw Error(4, dataSetName);
+            if (!isHex(dataSetName, 4, "0x")) throw Error(kerInvalidDataset, dataSetName);
             std::istringstream is(dataSetName);
             is >> std::hex >> dataSet;
         }
@@ -571,7 +565,7 @@ namespace Exiv2 {
             if (recordInfo_[i].name_ == recordName) break;
         }
         if (i == 0) {
-            if (!isHex(recordName, 4, "0x")) throw Error(5, recordName);
+            if (!isHex(recordName, 4, "0x")) throw Error(kerInvalidRecord, recordName);
             std::istringstream is(recordName);
             is >> std::hex >> i;
         }
@@ -676,18 +670,18 @@ namespace Exiv2 {
     {
         // Get the family name, record name and dataSet name parts of the key
         std::string::size_type pos1 = key_.find('.');
-        if (pos1 == std::string::npos) throw Error(6, key_);
+        if (pos1 == std::string::npos) throw Error(kerInvalidKey, key_);
         std::string familyName = key_.substr(0, pos1);
         if (0 != strcmp(familyName.c_str(), familyName_)) {
-            throw Error(6, key_);
+            throw Error(kerInvalidKey, key_);
         }
         std::string::size_type pos0 = pos1 + 1;
         pos1 = key_.find('.', pos0);
-        if (pos1 == std::string::npos) throw Error(6, key_);
+        if (pos1 == std::string::npos) throw Error(kerInvalidKey, key_);
         std::string recordName = key_.substr(pos0, pos1 - pos0);
-        if (recordName == "") throw Error(6, key_);
+        if (recordName == "") throw Error(kerInvalidKey, key_);
         std::string dataSetName = key_.substr(pos1 + 1);
-        if (dataSetName == "") throw Error(6, key_);
+        if (dataSetName == "") throw Error(kerInvalidKey, key_);
 
         // Use the parts of the key to find dataSet and recordId
         uint16_t recId = IptcDataSets::recordId(recordName);
@@ -728,8 +722,16 @@ namespace Exiv2 {
            << iptcKey.key() << ", "
            << TypeInfo::typeName(
               IptcDataSets::dataSetType(dataSet.number_,
-                                          dataSet.recordId_)) << ", "
-           << dataSet.desc_;
+                                        dataSet.recordId_)) << ", ";
+        // CSV encoded I am \"dead\" beat" => "I am ""dead"" beat"
+        char Q = '"';
+        os << Q;
+        for ( size_t i = 0 ; i < ::strlen(dataSet.desc_) ; i++ ) {
+            char c = dataSet.desc_[i];
+            if ( c == Q ) os << Q;
+            os << c;
+        }
+        os << Q;
         os.flags(f);
         return os;
     }
