@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2018 Exiv2 authors
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -17,12 +17,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-/*
-  File:      orfimage.cpp
-  Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
-  History:   13-May-06, ahu: created
-  Credits:   See header file
- */
 // *****************************************************************************
 // included header files
 #include "config.h"
