@@ -1,7 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2013 Andreas Huggel <ahuggel@gmx.net>
- *
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -18,19 +17,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-/*!
-  @file    panasonicmn_int.hpp
-  @brief   Panasonic MakerNote implemented using the following references:
-           <a href="http://www.compton.nu/panasonic.html">Panasonic MakerNote Information</a> by Tom Hughes,
-           Panasonic.pm of <a href="http://www.sno.phy.queensu.ca/~phil/exiftool/">ExifTool</a> by Phil Harvey,
-           <a href="http://www.ozhiker.com/electronics/pjmt/jpeg_info/panasonic_mn.html">Panasonic Makernote Format Specification</a> by Evan Hunter.
-  @version $Rev: 3091 $
-  @author  Andreas Huggel (ahu)
-           <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
-  @author  Gilles Caulier (gc)
-           <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
-  @date    11-Jun-05, ahu: created
- */
 #ifndef PANASONICMN_INT_HPP_
 #define PANASONICMN_INT_HPP_
 
@@ -65,6 +51,24 @@ namespace Exiv2 {
         static std::ostream& print0x000f(std::ostream& os, const Value& value, const ExifData*);
         //! Print WhiteBalanceBias
         static std::ostream& print0x0023(std::ostream& os, const Value& value, const ExifData*);
+        //! Print TimeSincePowerOn
+        static std::ostream& print0x0029(std::ostream& os, const Value& value, const ExifData*);
+        //! Print Baby age
+        static std::ostream& print0x0033(std::ostream& os, const Value& value, const ExifData*);
+        //! Print Travel days
+        static std::ostream& print0x0036(std::ostream& os, const Value& value, const ExifData*);
+        //! Print ISO
+        static std::ostream& print0x003c(std::ostream& os, const Value& value, const ExifData*);
+        //! Print Manometer Pressure
+        static std::ostream& printPressure(std::ostream& os, const Value& value, const ExifData*);
+        //! Print special text values: title, landmark, county and so on
+        static std::ostream& printPanasonicText(std::ostream& os, const Value& value, const ExifData*);
+        //! Print accerometer readings
+        static std::ostream& printAccelerometer(std::ostream& os, const Value& value, const ExifData*);
+        //! Print roll angle
+        static std::ostream& printRollAngle(std::ostream& os, const Value& value, const ExifData*);
+        //! Print pitch angle
+        static std::ostream& printPitchAngle(std::ostream& os, const Value& value, const ExifData*);
         //@}
 
     private:
