@@ -1,7 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2011 Andreas Huggel <ahuggel@gmx.net>
- *
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -18,14 +17,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-/*!
-  @file    tiffcomposite_int.hpp
-  @brief   Internal classes used in a TIFF composite structure
-  @version $Rev: 2453 $
-  @author  Andreas Huggel (ahu)
-           <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
-  @date    11-Apr-06, ahu: created
- */
 #ifndef TIFFCOMPOSITE_INT_HPP_
 #define TIFFCOMPOSITE_INT_HPP_
 
@@ -78,11 +69,15 @@ namespace Exiv2 {
       Special TIFF tags for the use in TIFF structures only
     */
     namespace Tag {
-        const uint32_t none = 0x10000; //!< Dummy tag
-        const uint32_t root = 0x20000; //!< Special tag: root IFD
-        const uint32_t next = 0x30000; //!< Special tag: next IFD
-        const uint32_t all  = 0x40000; //!< Special tag: all tags in a group
-        const uint32_t pana = 0x80000; //!< Special tag: root IFD of Panasonic RAW images
+        const uint32_t none      =  0x10000; //!< Dummy tag
+        const uint32_t root      =  0x20000; //!< Special tag: root IFD
+        const uint32_t next      =  0x30000; //!< Special tag: next IFD
+        const uint32_t all       =  0x40000; //!< Special tag: all tags in a group
+        const uint32_t pana      =  0x80000; //!< Special tag: root IFD of Panasonic RAW images
+        const uint32_t fuji      = 0x100000; //!< Special tag: root IFD of Fujifilm RAF images
+        const uint32_t cmt2      = 0x110000; //!< Special tag: root IFD of CR3 images
+        const uint32_t cmt3      = 0x120000; //!< Special tag: root IFD of CR3 images
+        const uint32_t cmt4      = 0x130000; //!< Special tag: root IFD of CR3 images
     }
 
     /*!
@@ -130,10 +125,10 @@ namespace Exiv2 {
         /*!
           brief Constructor.
 
-          The IO wrapper owns neither of the objects passed in so the caller is
+          The IO wrapper owns none of the objects passed in so the caller is
           responsible to keep them alive.
          */
-        IoWrapper(BasicIo& io, const byte* pHeader, long size);
+        IoWrapper(BasicIo& io, const byte* pHeader, long size, OffsetWriter* pow);
         //@}
 
         //! @name Manipulators
@@ -152,6 +147,8 @@ namespace Exiv2 {
           by the data passed in the argument.
          */
         int putb(byte data);
+        //! Wrapper for OffsetWriter::setTarget(), using an int instead of the enum to reduce include deps
+        void setTarget(int id, uint32_t target);
         //@}
 
     private:
@@ -160,6 +157,7 @@ namespace Exiv2 {
         const byte* pHeader_;      //! Pointer to the header data.
         long size_;                //! Size of the header data.
         bool wroteHeader_;         //! Indicates if the header has been written.
+        OffsetWriter* pow_;        //! Pointer to an offset-writer, if any, or 0
     }; // class IoWrapper
 
     /*!
@@ -859,6 +857,7 @@ namespace Exiv2 {
      */
     class TiffDirectory : public TiffComponent {
         friend class TiffEncoder;
+        friend class TiffDecoder;
     public:
         //! @name Creators
         //@{
