@@ -1,7 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2015 Andreas Huggel <ahuggel@gmx.net>
- *
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -18,15 +17,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-/*!
-  @file    tiffvisitor_int.hpp
-  @brief   Internal operations on a TIFF composite tree, implemented as visitor
-           classes.
-  @version $Rev: 3777 $
-  @author  Andreas Huggel (ahu)
-           <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
-  @date    11-Apr-06, ahu: created
- */
 #ifndef TIFFVISITOR_INT_HPP_
 #define TIFFVISITOR_INT_HPP_
 
@@ -59,7 +49,7 @@ namespace Exiv2 {
 
     /*!
       @brief Abstract base class defining the interface for TIFF composite
-             vistors (Visitor pattern)
+             visitors (Visitor pattern)
 
       A concrete visitor class is used as shown in the example below. Accept()
       will invoke the member function corresponding to the concrete type of each
@@ -219,7 +209,7 @@ namespace Exiv2 {
     }; // class TiffFinder
 
     /*!
-      @brief Copy all image tags from the source tree (the tree that is traversed) to a 
+      @brief Copy all image tags from the source tree (the tree that is traversed) to a
              target tree, which is empty except for the root element provided in the
              constructor.
     */
@@ -231,7 +221,7 @@ namespace Exiv2 {
           @brief Constructor
 
           @param pRoot Pointer to the root element of the (empty) target tree.
-          @param root 
+          @param root
           @param pHeader Pointer to the TIFF header of the source image.
           @param pPrimaryGroups Pointer to the list of primary groups.
          */
@@ -334,6 +324,8 @@ namespace Exiv2 {
         void decodeIptc(const TiffEntryBase* object);
         //! Decode XMP packet from an XMLPacket tag
         void decodeXmp(const TiffEntryBase* object);
+        //! Decode Exif.Canon.AFInfo
+        void decodeCanonAFInfo(const TiffEntryBase* object);
         //@}
 
     private:
@@ -548,7 +540,7 @@ namespace Exiv2 {
                                 ByteOrder byteOrder,
                                 TiffComponent* pTiffComponent) const;
         /*!
-          @brief Check if the tag is an image tag of an existing image. Such 
+          @brief Check if the tag is an image tag of an existing image. Such
                  tags are copied from the original image and can't be modifed.
 
                  The condition is true if there is an existing image (as
