@@ -1,7 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2017 Andreas Huggel <ahuggel@gmx.net>
- *
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -18,19 +17,9 @@
  * along with this f; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-/*
-  File:      xmp.cpp
-  Version:   $Rev$
-  Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
-  History:   13-July-07, ahu: created
- */
-// *****************************************************************************
-#include "rcsid_int.hpp"
-EXIV2_RCSID("@(#) $Id$")
-
 // *****************************************************************************
 // included header files
-#include "xmp.hpp"
+#include "xmp_exiv2.hpp"
 #include "types.hpp"
 #include "error.hpp"
 #include "value.hpp"
@@ -43,12 +32,184 @@ EXIV2_RCSID("@(#) $Id$")
 #include <string>
 
 // Adobe XMP Toolkit
-#ifdef EXV_HAVE_XMP_TOOLKIT
+#ifdef   EXV_HAVE_XMP_TOOLKIT
+# include <expat.h>
 # define TXMP_STRING_TYPE std::string
+# ifdef  EXV_ADOBE_XMPSDK
+# include <XMP.hpp>
+# else
 # include <XMPSDK.hpp>
+# endif
 # include <XMP.incl_cpp>
 #endif // EXV_HAVE_XMP_TOOLKIT
 
+#ifdef EXV_HAVE_XMP_TOOLKIT
+// This anonymous namespace contains a class named XMLValidator, which uses
+// libexpat to do a basic validation check on an XML document. This is to
+// reduce the chance of hitting a bug in the (third-party) xmpsdk
+// library. For example, it is easy to a trigger a stack overflow in xmpsdk
+// with a deeply nested tree.
+namespace {
+    using namespace Exiv2;
+
+    class XMLValidator {
+        size_t element_depth_;
+        size_t namespace_depth_;
+
+        // These fields are used to record whether an error occurred during
+        // parsing. Why do we need to store the error for later, rather
+        // than throw an exception immediately? Because expat is a C
+        // library, so it isn't designed to be able to handle exceptions
+        // thrown by the callback functions. Throwing exceptions during
+        // parsing is an example of one of the things that xmpsdk does
+        // wrong, leading to problems like https://github.com/Exiv2/exiv2/issues/1821.
+        bool haserror_;
+        std::string errmsg_;
+        XML_Size errlinenum_;
+        XML_Size errcolnum_;
+
+        // Very deeply nested XML trees can cause a stack overflow in
+        // xmpsdk.  They are also very unlikely to be valid XMP, so we
+        // error out if the depth exceeds this limit.
+        static const size_t max_recursion_limit_ = 1000;
+
+        const XML_Parser parser_;
+
+    public:
+        // Runs an XML parser on `buf`. Throws an exception if the XML is invalid.
+        static void check(const char* buf, size_t buflen) {
+            XMLValidator validator;
+            validator.check_internal(buf, buflen);
+        }
+
+    private:
+        // Private constructor, because this class is only constructed by
+        // the (static) check method.
+        XMLValidator() :
+            element_depth_(0), namespace_depth_(0), haserror_(false),
+            errlinenum_(0), errcolnum_(0),
+            parser_(XML_ParserCreateNS(0, '@'))
+        {
+            if (!parser_) {
+                throw Error(kerXMPToolkitError, "Could not create expat parser");
+            }
+        }
+
+        ~XMLValidator() {
+            XML_ParserFree(parser_);
+        }
+
+        void setError(const char* msg) {
+            const XML_Size errlinenum = XML_GetCurrentLineNumber(parser_);
+            const XML_Size errcolnum = XML_GetCurrentColumnNumber(parser_);
+#ifndef SUPPRESS_WARNINGS
+            EXV_INFO << "Invalid XML at line " << errlinenum
+                     << ", column " << errcolnum
+                     << ": " << msg << "\n";
+#endif
+            // If this is the first error, then save it.
+            if (!haserror_) {
+                haserror_ = true;
+                errmsg_ = msg;
+                errlinenum_ = errlinenum;
+                errcolnum_ = errcolnum;
+            }
+        }
+
+        void check_internal(const char* buf, size_t buflen) {
+            if (buflen > static_cast<size_t>(std::numeric_limits<int>::max())) {
+                throw Error(kerXMPToolkitError, "Buffer length is greater than INT_MAX");
+            }
+
+            XML_SetUserData(parser_, this);
+            XML_SetElementHandler(parser_, startElement_cb, endElement_cb);
+            XML_SetNamespaceDeclHandler(parser_, startNamespace_cb, endNamespace_cb);
+            XML_SetStartDoctypeDeclHandler(parser_, startDTD_cb);
+
+            const XML_Status result = XML_Parse(parser_, buf, static_cast<int>(buflen), true);
+            if (result == XML_STATUS_ERROR) {
+                setError(XML_ErrorString(XML_GetErrorCode(parser_)));
+            }
+
+            if (haserror_) {
+                throw XMP_Error(kXMPErr_BadXML, "Error in XMLValidator");
+            }
+        }
+
+        void startElement(const XML_Char*, const XML_Char**) {
+            if (element_depth_ > max_recursion_limit_) {
+                setError("Too deeply nested");
+            }
+            ++element_depth_;
+        }
+
+        void endElement(const XML_Char*) {
+            if (element_depth_ > 0) {
+                --element_depth_;
+            } else {
+                setError("Negative depth");
+            }
+        }
+
+        void startNamespace(const XML_Char*, const XML_Char*) {
+            if (namespace_depth_ > max_recursion_limit_) {
+                setError("Too deeply nested");
+            }
+            ++namespace_depth_;
+        }
+
+        void endNamespace(const XML_Char*) {
+            if (namespace_depth_ > 0) {
+                --namespace_depth_;
+            } else {
+                setError("Negative depth");
+            }
+        }
+
+        void startDTD(const XML_Char*, const XML_Char*, const XML_Char*, int) {
+            // DOCTYPE is used for XXE attacks.
+            setError("DOCTYPE not supported");
+        }
+
+        // This callback function is called by libexpat. It's a static wrapper
+        // around startElement().
+        static void XMLCALL startElement_cb(
+            void* userData, const XML_Char* name, const XML_Char* *attrs
+        ) {
+            static_cast<XMLValidator*>(userData)->startElement(name, attrs);
+        }
+
+        // This callback function is called by libexpat. It's a static wrapper
+        // around endElement().
+        static void XMLCALL endElement_cb(void* userData, const XML_Char* name) {
+            static_cast<XMLValidator*>(userData)->endElement(name);
+        }
+
+        // This callback function is called by libexpat. It's a static wrapper
+        // around startNamespace().
+        static void XMLCALL startNamespace_cb(
+            void* userData, const XML_Char* prefix, const XML_Char* uri
+        ) {
+            static_cast<XMLValidator*>(userData)->startNamespace(prefix, uri);
+        }
+
+        // This callback function is called by libexpat. It's a static wrapper
+        // around endNamespace().
+        static void XMLCALL endNamespace_cb(void* userData, const XML_Char* prefix) {
+            static_cast<XMLValidator*>(userData)->endNamespace(prefix);
+        }
+
+        static void XMLCALL startDTD_cb(
+            void *userData, const XML_Char *doctypeName, const XML_Char *sysid,
+            const XML_Char *pubid, int has_internal_subset
+        ) {
+            static_cast<XMLValidator*>(userData)->startDTD(
+                doctypeName, sysid, pubid, has_internal_subset);
+        }
+    };
+}  // namespace
+#endif // EXV_HAVE_XMP_TOOLKIT
+
 // *****************************************************************************
 // local declarations
 namespace {
@@ -176,7 +337,6 @@ namespace Exiv2 {
 
     Xmpdatum::~Xmpdatum()
     {
-        delete p_;
     }
 
     std::string Xmpdatum::key() const
@@ -266,13 +426,13 @@ namespace Exiv2 {
 
     const Value& Xmpdatum::value() const
     {
-        if (p_->value_.get() == 0) throw Error(8);
+        if (p_->value_.get() == 0) throw Error(kerValueNotSet);
         return *p_->value_;
     }
 
     long Xmpdatum::copy(byte* /*buf*/, ByteOrder /*byteOrder*/) const
     {
-        throw Error(34, "Xmpdatum::copy");
+        throw Error(kerFunctionNotSupported, "Xmpdatum::copy");
         return 0;
     }
 
@@ -316,8 +476,8 @@ namespace Exiv2 {
         XmpKey xmpKey(key);
         iterator pos = findKey(xmpKey);
         if (pos == end()) {
-            add(Xmpdatum(xmpKey));
-            pos = findKey(xmpKey);
+            xmpMetadata_.push_back(Xmpdatum(xmpKey));
+            return xmpMetadata_.back();
         }
         return *pos;
     }
@@ -385,11 +545,37 @@ namespace Exiv2 {
         return xmpMetadata_.end();
     }
 
-    XmpData::iterator XmpData::erase(XmpData::iterator pos)
-    {
+    XmpData::iterator XmpData::erase(XmpData::iterator pos) {
         return xmpMetadata_.erase(pos);
     }
 
+    void XmpData::eraseFamily(XmpData::iterator& pos)
+    {
+        // https://github.com/Exiv2/exiv2/issues/521
+        // delete 'children' of XMP composites (XmpSeq and XmpBag)
+
+        // I build a StringVector of keys to remove
+        // Then I remove them with erase(....)
+        // erase() has nasty side effects on its argument
+        // The side effects are avoided by the two-step approach
+        // https://github.com/Exiv2/exiv2/issues/560
+        std::string         key(pos->key());
+        Exiv2::StringVector keys;
+        while ( pos != xmpMetadata_.end() ) {
+            if ( pos->key().find(key)==0 ) {
+                keys.push_back(pos->key());
+                pos++;
+            } else {
+                break;
+            }
+        }
+        // now erase the family!
+        for ( Exiv2::StringVector_i it = keys.begin() ; it != keys.end() ; it++ ) {
+            erase(findKey(Exiv2::XmpKey(*it)));
+        }
+    }
+
+
     bool XmpParser::initialized_ = false;
     XmpParser::XmpLockFct XmpParser::xmpLockFct_ = 0;
     void* XmpParser::pLockData_ = 0;
@@ -401,6 +587,30 @@ namespace Exiv2 {
             xmpLockFct_ = xmpLockFct;
             pLockData_ = pLockData;
             initialized_ = SXMPMeta::Initialize();
+#ifdef EXV_ADOBE_XMPSDK
+            SXMPMeta::RegisterNamespace("http://ns.adobe.com/lightroom/1.0/", "lr",NULL);
+            SXMPMeta::RegisterNamespace("http://rs.tdwg.org/dwc/index.htm", "dwc",NULL);
+            SXMPMeta::RegisterNamespace("http://purl.org/dc/terms/", "dcterms",NULL);
+            SXMPMeta::RegisterNamespace("http://www.digikam.org/ns/1.0/", "digiKam",NULL);
+            SXMPMeta::RegisterNamespace("http://www.digikam.org/ns/kipi/1.0/", "kipi",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.microsoft.com/photo/1.0/", "MicrosoftPhoto",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.acdsee.com/iptc/1.0/", "acdsee",NULL);
+            SXMPMeta::RegisterNamespace("http://iptc.org/std/Iptc4xmpExt/2008-02-29/", "iptcExt",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.useplus.org/ldf/xmp/1.0/", "plus",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.iview-multimedia.com/mediapro/1.0/", "mediapro",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.microsoft.com/expressionmedia/1.0/", "expressionmedia",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.microsoft.com/photo/1.2/", "MP",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.microsoft.com/photo/1.2/t/RegionInfo#", "MPRI",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.microsoft.com/photo/1.2/t/Region#", "MPReg",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.google.com/photos/1.0/panorama/", "GPano",NULL);
+            SXMPMeta::RegisterNamespace("http://www.metadataworkinggroup.com/schemas/regions/", "mwg-rs",NULL);
+            SXMPMeta::RegisterNamespace("http://www.metadataworkinggroup.com/schemas/keywords/", "mwg-kw",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.adobe.com/xmp/sType/Area#", "stArea",NULL);
+            SXMPMeta::RegisterNamespace("http://cipa.jp/exif/1.0/", "exifEX",NULL);
+            SXMPMeta::RegisterNamespace("http://ns.adobe.com/camera-raw-saved-settings/1.0/", "crss",NULL);
+            SXMPMeta::RegisterNamespace("http://www.audio/", "audio",NULL);
+            SXMPMeta::RegisterNamespace("http://www.video/", "video",NULL);
+#else
             SXMPMeta::RegisterNamespace("http://ns.adobe.com/lightroom/1.0/", "lr");
             SXMPMeta::RegisterNamespace("http://rs.tdwg.org/dwc/index.htm", "dwc");
             SXMPMeta::RegisterNamespace("http://purl.org/dc/terms/", "dcterms");
@@ -420,16 +630,17 @@ namespace Exiv2 {
             SXMPMeta::RegisterNamespace("http://www.metadataworkinggroup.com/schemas/keywords/", "mwg-kw");
             SXMPMeta::RegisterNamespace("http://ns.adobe.com/xmp/sType/Area#", "stArea");
             SXMPMeta::RegisterNamespace("http://cipa.jp/exif/1.0/", "exifEX");
-		    SXMPMeta::RegisterNamespace("http://ns.adobe.com/camera-raw-saved-settings/1.0/", "crss");
+            SXMPMeta::RegisterNamespace("http://ns.adobe.com/camera-raw-saved-settings/1.0/", "crss");
             SXMPMeta::RegisterNamespace("http://www.audio/", "audio");
             SXMPMeta::RegisterNamespace("http://www.video/", "video");
+#endif
         }
         return initialized_;
     }
 #else
     bool XmpParser::initialize(XmpParser::XmpLockFct, void* )
     {
-    	initialized_ = true;
+        initialized_ = true;
         return initialized_;
     }
 #endif
@@ -449,17 +660,17 @@ namespace Exiv2 {
         out.erase(end_pos, out.end());
 
         bool bURI = out.find("http://") != std::string::npos   ;
-        bool bNS  = out.find(":") != std::string::npos && !bURI;
+        bool bNS  = out.find(':') != std::string::npos && !bURI;
 
         // pop trailing ':' on a namespace
-        if ( bNS ) {
-	    std::size_t length = out.length();
+        if ( bNS && !out.empty() ) {
+            std::size_t length = out.length();
             if ( out[length-1] == ':' ) out = out.substr(0,length-1);
         }
 
         if ( bURI || bNS ) {
             std::map<std::string,std::string>* p = (std::map<std::string,std::string>*) refCon;
-            std::map<std::string,std::string>& m = (std::map<std::string,std::string>&) *p    ;
+            std::map<std::string,std::string>& m = *p;
 
             std::string b("");
             if ( bNS ) {  // store the NS in dict[""]
@@ -476,13 +687,13 @@ namespace Exiv2 {
 #ifdef EXV_HAVE_XMP_TOOLKIT
     void XmpParser::registeredNamespaces(Exiv2::Dictionary& dict)
     {
-    	bool bInit = !initialized_;
+        bool bInit = !initialized_;
         try {
-        	if (bInit) initialize();
-        	SXMPMeta::DumpNamespaces(nsDumper,&dict);
-        	if (bInit) terminate();
+            if (bInit) initialize();
+            SXMPMeta::DumpNamespaces(nsDumper,&dict);
+            if (bInit) terminate();
         } catch (const XMP_Error& e) {
-            throw Error(40, e.GetID(), e.GetErrMsg());
+            throw Error(kerXMPToolkitError, e.GetID(), e.GetErrMsg());
         }
     }
 #else
@@ -508,10 +719,14 @@ namespace Exiv2 {
             initialize();
             AutoLock autoLock(xmpLockFct_, pLockData_);
             SXMPMeta::DeleteNamespace(ns.c_str());
+#ifdef EXV_ADOBE_XMPSDK
+            SXMPMeta::RegisterNamespace(ns.c_str(), prefix.c_str(),NULL);
+#else
             SXMPMeta::RegisterNamespace(ns.c_str(), prefix.c_str());
+#endif
         }
-        catch (const XMP_Error& e) {
-            throw Error(40, e.GetID(), e.GetErrMsg());
+        catch (const XMP_Error& /* e */) {
+            // throw Error(kerXMPToolkitError, e.GetID(), e.GetErrMsg());
         }
     } // XmpParser::registerNs
 #else
@@ -530,7 +745,7 @@ namespace Exiv2 {
 //          SXMPMeta::DeleteNamespace(ns.c_str());
         }
         catch (const XMP_Error& e) {
-            throw Error(40, e.GetID(), e.GetErrMsg());
+            throw Error(kerXMPToolkitError, e.GetID(), e.GetErrMsg());
         }
 #endif
     } // XmpParser::unregisterNs
@@ -550,14 +765,19 @@ namespace Exiv2 {
             return 2;
         }
 
-        SXMPMeta meta(xmpPacket.data(), static_cast<XMP_StringLen>(xmpPacket.size()));
+        // Make sure the unterminated substring is used
+        size_t len = xmpPacket.size();
+        while (len > 0 && 0 == xmpPacket[len - 1]) --len;
+
+        XMLValidator::check(xmpPacket.data(), len);
+        SXMPMeta meta(xmpPacket.data(), static_cast<XMP_StringLen>(len));
         SXMPIterator iter(meta);
         std::string schemaNs, propPath, propValue;
-        XMP_OptionBits opt;
+        XMP_OptionBits opt = 0;
         while (iter.Next(&schemaNs, &propPath, &propValue, &opt)) {
             printNode(schemaNs, propPath, propValue, opt);
             if (XMP_PropIsAlias(opt)) {
-                throw Error(47, schemaNs, propPath, propValue);
+                throw Error(kerAliasesNotSupported, schemaNs, propPath, propValue);
                 continue;
             }
             if (XMP_NodeIsSchema(opt)) {
@@ -566,7 +786,7 @@ namespace Exiv2 {
                 if (XmpProperties::prefix(schemaNs).empty()) {
                     std::string prefix;
                     bool ret = meta.GetNamespacePrefix(schemaNs.c_str(), &prefix);
-                    if (!ret) throw Error(45, schemaNs);
+                    if (!ret) throw Error(kerSchemaNamespaceNotRegistered, schemaNs);
                     prefix = prefix.substr(0, prefix.size() - 1);
                     XmpProperties::registerNs(schemaNs, prefix);
                 }
@@ -584,7 +804,7 @@ namespace Exiv2 {
                     if (   !haveNext
                         || !XMP_PropIsSimple(opt)
                         || !XMP_PropHasLang(opt)) {
-                        throw Error(41, propPath, opt);
+                        throw Error(kerDecodeLangAltPropertyFailed, propPath, opt);
                     }
                     const std::string text = propValue;
                     // Get the language qualifier
@@ -594,7 +814,7 @@ namespace Exiv2 {
                         || !XMP_PropIsSimple(opt)
                         || !XMP_PropIsQualifier(opt)
                         || propPath.substr(propPath.size() - 8, 8) != "xml:lang") {
-                        throw Error(42, propPath, opt);
+                        throw Error(kerDecodeLangAltQualifierFailed, propPath, opt);
                     }
                     val->value_[propValue] = text;
                 }
@@ -608,7 +828,7 @@ namespace Exiv2 {
                 bool simpleArray = true;
                 SXMPIterator aIter(meta, schemaNs.c_str(), propPath.c_str());
                 std::string aSchemaNs, aPropPath, aPropValue;
-                XMP_OptionBits aOpt;
+                XMP_OptionBits aOpt = 0;
                 while (aIter.Next(&aSchemaNs, &aPropPath, &aPropValue, &aOpt)) {
                     if (propPath == aPropPath) continue;
                     if (   !XMP_PropIsSimple(aOpt)
@@ -649,14 +869,14 @@ namespace Exiv2 {
                 continue;
             }
             // Don't let any node go by unnoticed
-            throw Error(39, key->key(), opt);
+            throw Error(kerUnhandledXmpNode, key->key(), opt);
         } // iterate through all XMP nodes
 
         return 0;
     }
 #ifndef SUPPRESS_WARNINGS
     catch (const XMP_Error& e) {
-        EXV_ERROR << Error(40, e.GetID(), e.GetErrMsg()) << "\n";
+        EXV_ERROR << Error(kerXMPToolkitError, e.GetID(), e.GetErrMsg()) << "\n";
         xmpData.clear();
         return 3;
     }
@@ -701,7 +921,7 @@ namespace Exiv2 {
         // Register custom namespaces with XMP-SDK
         for (XmpProperties::NsRegistry::iterator i = XmpProperties::nsRegistry_.begin();
              i != XmpProperties::nsRegistry_.end(); ++i) {
-#ifdef DEBUG
+#ifdef EXIV2_DEBUG_MESSAGES
             std::cerr << "Registering " << i->second.prefix_ << " : " << i->first << "\n";
 #endif
             registerNs(i->first, i->second.prefix_);
@@ -715,7 +935,7 @@ namespace Exiv2 {
 
                 // Encode Lang Alt property
                 const LangAltValue* la = dynamic_cast<const LangAltValue*>(&i->value());
-                if (la == 0) throw Error(43, i->key());
+                if (la == 0) throw Error(kerEncodeLangAltPropertyFailed, i->key());
 
                 int idx = 1;
                 for ( LangAltValue::ValueType::const_iterator k = la->value_.begin()
@@ -734,7 +954,7 @@ namespace Exiv2 {
 
             // Todo: Xmpdatum should have an XmpValue, not a Value
             const XmpValue* val = dynamic_cast<const XmpValue*>(&i->value());
-            if (val == 0) throw Error(52, i->key(), i->typeName());
+            if (val == 0) throw Error(kerInvalidKeyXmpValue, i->key(), i->typeName());
             options =   xmpArrayOptionBits(val->xmpArrayType())
                       | xmpArrayOptionBits(val->xmpStruct());
             if (   i->typeId() == xmpBag
@@ -742,7 +962,7 @@ namespace Exiv2 {
                 || i->typeId() == xmpAlt) {
                 printNode(ns, i->tagName(), "", options);
                 meta.SetProperty(ns.c_str(), i->tagName().c_str(), 0, options);
-                for (int idx = 0; idx < i->count(); ++idx) {
+                for (long idx = 0; idx < i->count(); ++idx) {
                     const std::string item = i->tagName() + "[" + toString(idx + 1) + "]";
                     printNode(ns, item, i->toString(idx), 0);
                     meta.SetProperty(ns.c_str(), item.c_str(), i->toString(idx).c_str());
@@ -761,7 +981,7 @@ namespace Exiv2 {
                 continue;
             }
             // Don't let any Xmpdatum go by unnoticed
-            throw Error(38, i->tagName(), i->typeName());
+            throw Error(kerUnhandledXmpdatum, i->tagName(), i->typeName());
         }
         std::string tmpPacket;
         meta.SerializeToBuffer(&tmpPacket, xmpFormatOptionBits(static_cast<XmpFormatFlags>(formatFlags)), padding); // throws
@@ -771,7 +991,7 @@ namespace Exiv2 {
     }
 #ifndef SUPPRESS_WARNINGS
     catch (const XMP_Error& e) {
-        EXV_ERROR << Error(40, e.GetID(), e.GetErrMsg()) << "\n";
+        EXV_ERROR << Error(kerXMPToolkitError, e.GetID(), e.GetErrMsg()) << "\n";
         return 3;
     }
 #else
@@ -861,6 +1081,10 @@ namespace {
         return var;
     }
 
+#ifdef  EXV_ADOBE_XMPSDK
+#define kXMP_WriteAliasComments  0x0400UL
+#endif
+
     XMP_OptionBits xmpFormatOptionBits(Exiv2::XmpParser::XmpFormatFlags flags)
     {
         XMP_OptionBits var(0);
@@ -874,7 +1098,7 @@ namespace {
         return var;
     }
 
-#ifdef DEBUG
+#ifdef EXIV2_DEBUG_MESSAGES
     void printNode(const std::string& schemaNs,
                    const std::string& propPath,
                    const std::string& propValue,
@@ -917,7 +1141,7 @@ namespace {
                    const std::string& ,
                    const XMP_OptionBits& )
     {}
-#endif // DEBUG
+#endif // EXIV2_DEBUG_MESSAGES
 
     Exiv2::XmpKey::AutoPtr makeXmpKey(const std::string& schemaNs,
                                       const std::string& propPath)
@@ -925,13 +1149,13 @@ namespace {
         std::string property;
         std::string::size_type idx = propPath.find(':');
         if (idx == std::string::npos) {
-            throw Exiv2::Error(44, propPath, schemaNs);
+            throw Exiv2::Error(Exiv2::kerPropertyNameIdentificationFailed, propPath, schemaNs);
         }
         // Don't worry about out_of_range, XMP parser takes care of this
         property = propPath.substr(idx + 1);
         std::string prefix = Exiv2::XmpProperties::prefix(schemaNs);
         if (prefix.empty()) {
-            throw Exiv2::Error(36, propPath, schemaNs);
+            throw Exiv2::Error(Exiv2::kerNoPrefixForNamespace, propPath, schemaNs);
         }
         return Exiv2::XmpKey::AutoPtr(new Exiv2::XmpKey(prefix, property));
     } // makeXmpKey
